Build -> Install
authorMathieu Lacage <mathieu.lacage@sophia.inria.fr>
Mon, 07 Apr 2008 10:38:37 -0700
changeset 2887 9a637e6daee0
parent 2886 8226157800a8
child 2888 872dc8466352
Build -> Install
examples/csma-broadcast.cc
examples/csma-multicast.cc
examples/csma-one-subnet.cc
examples/csma-packet-socket.cc
examples/mixed-global-routing.cc
examples/simple-alternate-routing.cc
examples/simple-error-model.cc
examples/simple-global-routing.cc
examples/simple-point-to-point-olsr.cc
examples/tcp-large-transfer.cc
examples/udp-echo.cc
examples/wifi-adhoc.cc
examples/wifi-ap.cc
samples/main-simple.cc
src/helper/csma-helper.cc
src/helper/csma-helper.h
src/helper/internet-stack-helper.cc
src/helper/internet-stack-helper.h
src/helper/on-off-helper.cc
src/helper/on-off-helper.h
src/helper/packet-sink-helper.cc
src/helper/packet-sink-helper.h
src/helper/packet-socket-helper.cc
src/helper/packet-socket-helper.h
src/helper/point-to-point-helper.cc
src/helper/point-to-point-helper.h
src/helper/udp-echo-helper.cc
src/helper/udp-echo-helper.h
src/helper/wifi-helper.cc
src/helper/wifi-helper.h
tutorial/tutorial-bus-network.cc
tutorial/tutorial-csma-echo-ascii-trace.cc
tutorial/tutorial-csma-echo-pcap-trace.cc
tutorial/tutorial-csma-echo.cc
tutorial/tutorial-linear-dumbbell.cc
tutorial/tutorial-point-to-point.cc
tutorial/tutorial-star-routing.cc
tutorial/tutorial-star.cc
--- a/examples/csma-broadcast.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/csma-broadcast.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -70,13 +70,13 @@
   csma.SetChannelParameter ("BitRate", DataRate(5000000));
   csma.SetChannelParameter ("Delay", MilliSeconds(2));
 
-  NetDeviceContainer n0 = csma.Build (c0);
-  NetDeviceContainer n1 = csma.Build (c1);
+  NetDeviceContainer n0 = csma.Install (c0);
+  NetDeviceContainer n1 = csma.Install (c1);
 
 
   InternetStackHelper internet;
-  internet.Build (c0);
-  internet.Build (c1);
+  internet.Install (c0);
+  internet.Install (c1);
 
   NS_LOG_INFO ("Assign IP Addresses.");
   Ipv4AddressHelper ipv4;
@@ -99,7 +99,7 @@
   onoff.SetAppAttribute ("OnTime", ConstantVariable (1));
   onoff.SetAppAttribute ("OffTime", ConstantVariable (0));
 
-  ApplicationContainer app = onoff.Build (c0.Get (0));
+  ApplicationContainer app = onoff.Install (c0.Get (0));
   // Start the application
   app.Start (Seconds (1.0));
   app.Stop (Seconds (10.0));
@@ -107,8 +107,8 @@
   // Create an optional packet sink to receive these packets
   PacketSinkHelper sink;
   sink.SetupUdp (Ipv4Address::GetAny (), port);
-  sink.Build (c0.Get (1));
-  sink.Build (c1.Get (1));
+  sink.Install (c0.Get (1));
+  sink.Install (c1.Get (1));
 
 
   // Also configure some tcpdump traces; each interface will be traced
--- a/examples/csma-multicast.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/csma-multicast.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -78,13 +78,13 @@
   csma.SetChannelParameter ("Delay", MilliSeconds (2));
  
   // We will use these NetDevice containers later, for IP addressing
-  NetDeviceContainer nd0 = csma.Build (c0);  // First LAN
-  NetDeviceContainer nd1 = csma.Build (c1);  // Second LAN
+  NetDeviceContainer nd0 = csma.Install (c0);  // First LAN
+  NetDeviceContainer nd1 = csma.Install (c1);  // Second LAN
 
   NS_LOG_INFO ("Add IP Stack.");
   InternetStackHelper internet;
-  internet.Build (c0);
-  internet.Build (c1);
+  internet.Install (c0);
+  internet.Install (c1);
 
   NS_LOG_INFO ("Assign IP Addresses.");
   Ipv4AddressHelper ipv4Addr;
@@ -147,7 +147,7 @@
   onoff.SetAppAttribute ("DataRate", DataRate ("255b/s"));
   onoff.SetAppAttribute ("PacketSize", Uinteger (128));
 
-  ApplicationContainer srcC = onoff.Build (c0.Get (0));
+  ApplicationContainer srcC = onoff.Install (c0.Get (0));
 
   //
   // Tell the application when to start and stop.
@@ -158,7 +158,7 @@
   // Create an optional packet sink to receive these packets
   PacketSinkHelper sink;
   sink.SetupUdp (Ipv4Address::GetAny(), multicastPort);
-  ApplicationContainer sinkC = sink.Build (c1.Get (2)); // Node n4 
+  ApplicationContainer sinkC = sink.Install (c1.Get (2)); // Node n4 
   // Start the sink
   sinkC.Start (Seconds (1.0));
   sinkC.Stop (Seconds (10.0));
--- a/examples/csma-one-subnet.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/csma-one-subnet.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -76,10 +76,10 @@
 // created on the node.  Interpret nd0 as the net device we created for node
 // zero.
 //
-  NetDeviceContainer nd0 = csma.Build (c);
+  NetDeviceContainer nd0 = csma.Install (c);
 
   InternetStackHelper internet;
-  internet.Build (c);
+  internet.Install (c);
 
 // We've got the "hardware" in place.  Now we need to add IP addresses.
 //
@@ -99,7 +99,7 @@
   onoff.SetAppAttribute ("OnTime", ConstantVariable (1));
   onoff.SetAppAttribute ("OffTime", ConstantVariable (0));
 
-  ApplicationContainer app = onoff.Build (c.Get (0));
+  ApplicationContainer app = onoff.Install (c.Get (0));
   // Start the application
   app.Start (Seconds (1.0));
   app.Stop (Seconds (10.0));
@@ -107,15 +107,15 @@
   // Create an optional packet sink to receive these packets
   PacketSinkHelper sink;
   sink.SetupUdp (Ipv4Address::GetAny (), port);
-  sink.Build (c.Get (1));
+  sink.Install (c.Get (1));
 
 // 
 // Create a similar flow from n3 to n0, starting at time 1.1 seconds
 //
   onoff.SetUdpRemote (Ipv4Address("10.1.1.1"), port);
-  ApplicationContainer app2 = onoff.Build (c.Get (3));
+  ApplicationContainer app2 = onoff.Install (c.Get (3));
 
-  sink.Build (c.Get (0));
+  sink.Install (c.Get (0));
 
   app2.Start(Seconds (1.1));
   app2.Stop (Seconds (10.0));
--- a/examples/csma-packet-socket.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/csma-packet-socket.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -65,7 +65,7 @@
   c.Create (4);
 
   PacketSocketHelper packetSocket;
-  packetSocket.Build (c);
+  packetSocket.Install (c);
 
   // create the shared medium used by all csma devices.
   NS_LOG_INFO ("Create channels.");
@@ -76,7 +76,7 @@
   NS_LOG_INFO ("Build Topology.");
   CsmaHelper csma;
   csma.SetDeviceParameter ("EncapsulationMode", String ("Llc"));
-  NetDeviceContainer devs = csma.Build (c, channel);
+  NetDeviceContainer devs = csma.Install (c, channel);
 
   NS_LOG_INFO ("Create Applications.");
   // Create the OnOff application to send raw datagrams
@@ -84,13 +84,13 @@
   onoff.SetAppAttribute ("OnTime", ConstantVariable (1.0));
   onoff.SetAppAttribute ("OffTime", ConstantVariable (0.0));
   onoff.SetPacketRemote (devs.Get (0), devs.Get (1)->GetAddress (), 2);
-  ApplicationContainer apps = onoff.Build (c.Get (0));
+  ApplicationContainer apps = onoff.Install (c.Get (0));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
   
 
   onoff.SetPacketRemote (devs.Get (3), devs.Get (0)->GetAddress (), 3);
-  apps = onoff.Build (c.Get (3));
+  apps = onoff.Install (c.Get (3));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
  
--- a/examples/mixed-global-routing.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/mixed-global-routing.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -98,26 +98,26 @@
   NodeContainer n2345 = NodeContainer (c.Get (2), c.Get (3), c.Get (4), c.Get (5));
 
   InternetStackHelper internet;
-  internet.Build (c);
+  internet.Install (c);
 
   // We create the channels first without any IP addressing information
   NS_LOG_INFO ("Create channels.");
   PointToPointHelper p2p;
   p2p.SetChannelParameter ("BitRate", DataRate (5000000));
   p2p.SetChannelParameter ("Delay", MilliSeconds (2));
-  NetDeviceContainer d0d2 = p2p.Build (n0n2);
+  NetDeviceContainer d0d2 = p2p.Install (n0n2);
 
-  NetDeviceContainer d1d2 = p2p.Build (n1n2);
+  NetDeviceContainer d1d2 = p2p.Install (n1n2);
 
   p2p.SetChannelParameter ("BitRate", DataRate (1500000));
   p2p.SetChannelParameter ("Delay", MilliSeconds (10));
-  NetDeviceContainer d5d6 = p2p.Build (n5n6);
+  NetDeviceContainer d5d6 = p2p.Install (n5n6);
 
   // We create the channels first without any IP addressing information
   CsmaHelper csma;
   csma.SetChannelParameter ("BitRate", DataRate (5000000));
   csma.SetChannelParameter ("Delay", MilliSeconds (2));
-  NetDeviceContainer d2345 = csma.Build (n2345);
+  NetDeviceContainer d2345 = csma.Install (n2345);
   
   // Later, we add IP addresses.  
   NS_LOG_INFO ("Assign IP Addresses.");
@@ -148,7 +148,7 @@
   onoff.SetAppAttribute ("DataRate", DataRate("300bps"));
   onoff.SetAppAttribute ("PacketSize", Uinteger (50));
   onoff.SetUdpRemote (i5i6.GetAddress (1), port);
-  ApplicationContainer apps = onoff.Build (c.Get (0));
+  ApplicationContainer apps = onoff.Install (c.Get (0));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
--- a/examples/simple-alternate-routing.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/simple-alternate-routing.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -98,19 +98,19 @@
   PointToPointHelper p2p;
   p2p.SetChannelParameter ("BitRate", DataRate (5000000));
   p2p.SetChannelParameter ("Delay", MilliSeconds (2));
-  NetDeviceContainer d0d2 = p2p.Build (n0n2);
+  NetDeviceContainer d0d2 = p2p.Install (n0n2);
 
-  NetDeviceContainer d1d2 = p2p.Build (n1n2);
+  NetDeviceContainer d1d2 = p2p.Install (n1n2);
 
   p2p.SetChannelParameter ("BitRate", DataRate(1500000));
   p2p.SetChannelParameter ("Delay", MilliSeconds (10));
-  NetDeviceContainer d3d2 = p2p.Build (n3n2);
+  NetDeviceContainer d3d2 = p2p.Install (n3n2);
 
   p2p.SetChannelParameter ("Delay", MilliSeconds (100));
-  NetDeviceContainer d1d3 = p2p.Build (n1n3);
+  NetDeviceContainer d1d3 = p2p.Install (n1n3);
 
   InternetStackHelper internet;
-  internet.Build (c);
+  internet.Install (c);
   
   // Later, we add IP addresses.  The middle two octets correspond to 
  // the channel number.  
@@ -144,14 +144,14 @@
   onoff.SetAppAttribute ("OnTime", ConstantVariable (1));
   onoff.SetAppAttribute ("OffTime", ConstantVariable (0));
   onoff.SetUdpRemote (i1i2.GetAddress (0), port);
-  ApplicationContainer apps = onoff.Build (c.Get (3));
+  ApplicationContainer apps = onoff.Install (c.Get (3));
   apps.Start (Seconds (1.1));
   apps.Start (Seconds (10.0));
 
   // Create a packet sink to receive these packets
   PacketSinkHelper sink;
   sink.SetupUdp (Ipv4Address::GetAny (), port);
-  apps = sink.Build (c.Get (1));
+  apps = sink.Install (c.Get (1));
   apps.Start (Seconds (1.1));
   apps.Stop (Seconds (10.0));
 
--- a/examples/simple-error-model.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/simple-error-model.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -86,20 +86,20 @@
   NodeContainer n3n2 = NodeContainer (c.Get (3), c.Get (2));
 
   InternetStackHelper internet;
-  internet.Build (c);
+  internet.Install (c);
 
   // We create the channels first without any IP addressing information
   NS_LOG_INFO ("Create channels.");
   PointToPointHelper p2p;
   p2p.SetChannelParameter ("BitRate", DataRate (5000000));
   p2p.SetChannelParameter ("Delay", MilliSeconds (2));
-  NetDeviceContainer d0d2 = p2p.Build (n0n2);
+  NetDeviceContainer d0d2 = p2p.Install (n0n2);
 
-  NetDeviceContainer d1d2 = p2p.Build (n1n2);
+  NetDeviceContainer d1d2 = p2p.Install (n1n2);
 
   p2p.SetChannelParameter ("BitRate", DataRate (1500000));
   p2p.SetChannelParameter ("Delay", MilliSeconds (10));
-  NetDeviceContainer d3d2 = p2p.Build (n3n2);
+  NetDeviceContainer d3d2 = p2p.Install (n3n2);
   
   // Later, we add IP addresses.  
   NS_LOG_INFO ("Assign IP Addresses.");
@@ -124,26 +124,26 @@
   onoff.SetUdpRemote (i3i2.GetAddress (1), port);
   onoff.SetAppAttribute ("OnTime", ConstantVariable(1));
   onoff.SetAppAttribute ("OffTime", ConstantVariable(0));
-  ApplicationContainer apps = onoff.Build (c.Get (0));
+  ApplicationContainer apps = onoff.Install (c.Get (0));
   apps.Start(Seconds(1.0));
   apps.Stop (Seconds(10.0));
 
   // Create an optional packet sink to receive these packets
   PacketSinkHelper sink;
   sink.SetupUdp (Ipv4Address::GetAny (), port);
-  apps = sink.Build (c.Get (3));
+  apps = sink.Install (c.Get (3));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
   // Create a similar flow from n3 to n1, starting at time 1.1 seconds
   onoff.SetUdpRemote (i1i2.GetAddress (0), port);
-  apps = onoff.Build (c.Get (3));
+  apps = onoff.Install (c.Get (3));
   apps.Start(Seconds(1.1));
   apps.Stop (Seconds(10.0));
 
   // Create a packet sink to receive these packets
   sink.SetupUdp (Ipv4Address::GetAny (), port);
-  apps = sink.Build (c.Get (1));
+  apps = sink.Install (c.Get (1));
   apps.Start (Seconds (1.1));
   apps.Stop (Seconds (10.0));
 
--- a/examples/simple-global-routing.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/simple-global-routing.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -86,20 +86,20 @@
   NodeContainer n3n2 = NodeContainer (c.Get(3), c.Get (2));
 
   InternetStackHelper internet;
-  internet.Build (c);
+  internet.Install (c);
 
   // We create the channels first without any IP addressing information
   NS_LOG_INFO ("Create channels.");
   PointToPointHelper p2p;
   p2p.SetChannelParameter ("BitRate", DataRate (5000000));
   p2p.SetChannelParameter ("Delay", MilliSeconds (2));
-  NetDeviceContainer d0d2 = p2p.Build (n0n2);
+  NetDeviceContainer d0d2 = p2p.Install (n0n2);
 
-  NetDeviceContainer d1d2 = p2p.Build (n1n2);
+  NetDeviceContainer d1d2 = p2p.Install (n1n2);
   
   p2p.SetChannelParameter ("BitRate", DataRate (1500000));
   p2p.SetChannelParameter ("Delay", MilliSeconds (10));
-  NetDeviceContainer d3d2 = p2p.Build (n3n2);
+  NetDeviceContainer d3d2 = p2p.Install (n3n2);
   
   // Later, we add IP addresses.  
   NS_LOG_INFO ("Assign IP Addresses.");
@@ -125,25 +125,25 @@
   onoff.SetAppAttribute ("OnTime", ConstantVariable (1));
   onoff.SetAppAttribute ("OffTime", ConstantVariable (0));
   onoff.SetUdpRemote (i3i2.GetAddress (0), port);
-  ApplicationContainer apps = onoff.Build (c.Get (0));
+  ApplicationContainer apps = onoff.Install (c.Get (0));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
   // Create a packet sink to receive these packets
   PacketSinkHelper sink;
   sink.SetupUdp (Ipv4Address::GetAny (), port);
-  apps = sink.Build (c.Get (3));
+  apps = sink.Install (c.Get (3));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
   // Create a similar flow from n3 to n1, starting at time 1.1 seconds
   onoff.SetUdpRemote (i1i2.GetAddress (0), port);
-  apps = onoff.Build (c.Get (3));
+  apps = onoff.Install (c.Get (3));
   apps.Start (Seconds (1.1));
   apps.Stop (Seconds (10.0));
 
   // Create a packet sink to receive these packets
-  apps = sink.Build (c.Get (1));
+  apps = sink.Install (c.Get (1));
   apps.Start (Seconds (1.1));
   apps.Stop (Seconds (10.0));
 
--- a/examples/simple-point-to-point-olsr.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/simple-point-to-point-olsr.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -87,19 +87,19 @@
   NodeContainer n34 = NodeContainer (c.Get (3), c.Get (4));
 
   InternetStackHelper internet;
-  internet.Build (c);
+  internet.Install (c);
 
   // We create the channels first without any IP addressing information
   NS_LOG_INFO ("Create channels.");
   PointToPointHelper p2p;
   p2p.SetChannelParameter ("BitRate", DataRate (5000000));
   p2p.SetChannelParameter ("Delay", MilliSeconds (2));
-  NetDeviceContainer nd02 = p2p.Build (n02);
-  NetDeviceContainer nd12 = p2p.Build (n12);
+  NetDeviceContainer nd02 = p2p.Install (n02);
+  NetDeviceContainer nd12 = p2p.Install (n12);
   p2p.SetChannelParameter ("BitRate", DataRate (1500000));
   p2p.SetChannelParameter ("Delay", MilliSeconds (10));
-  NetDeviceContainer nd32 = p2p.Build (n32);
-  NetDeviceContainer nd34 = p2p.Build (n34);
+  NetDeviceContainer nd32 = p2p.Install (n32);
+  NetDeviceContainer nd34 = p2p.Install (n34);
   
   // Later, we add IP addresses.  
   NS_LOG_INFO ("Assign IP Addresses.");
@@ -129,25 +129,25 @@
   onoff.SetAppAttribute ("OnTime", ConstantVariable (1));
   onoff.SetAppAttribute ("OffTime", ConstantVariable (0));
   onoff.SetUdpRemote (i34.GetAddress (1), port);
-  ApplicationContainer apps = onoff.Build (c.Get (0));
+  ApplicationContainer apps = onoff.Install (c.Get (0));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
   // Create a packet sink to receive these packets
   PacketSinkHelper sink;
   sink.SetupUdp (Ipv4Address::GetAny (), port);
-  apps = sink.Build (c.Get (3));
+  apps = sink.Install (c.Get (3));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
   // Create a similar flow from n3 to n1, starting at time 1.1 seconds
   onoff.SetUdpRemote (i12.GetAddress (0), port);
-  apps = onoff.Build (c.Get (3));
+  apps = onoff.Install (c.Get (3));
   apps.Start (Seconds (1.1));
   apps.Stop (Seconds (10.0));
 
   // Create a packet sink to receive these packets
-  apps = sink.Build (c.Get (1));
+  apps = sink.Install (c.Get (1));
   apps.Start (Seconds (1.1));
   apps.Stop (Seconds (10.0));
 
--- a/examples/tcp-large-transfer.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/tcp-large-transfer.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -139,13 +139,13 @@
   PointToPointHelper p2p;
   p2p.SetChannelParameter ("BitRate", DataRate(10000000));
   p2p.SetChannelParameter ("Delay", MilliSeconds(10));
-  NetDeviceContainer dev0 = p2p.Build (c0);
-  NetDeviceContainer dev1 = p2p.Build (c1);
+  NetDeviceContainer dev0 = p2p.Install (c0);
+  NetDeviceContainer dev1 = p2p.Install (c1);
 
   // add ip/tcp stack to nodes.
   NodeContainer c = NodeContainer (c0, c1.Get (1));
   InternetStackHelper internet;
-  internet.Build (c);
+  internet.Install (c);
 
   // Later, we add IP addresses.  
   Ipv4AddressHelper ipv4;
@@ -171,7 +171,7 @@
   // Create a packet sink to receive these packets
   PacketSinkHelper sink;
   sink.SetupTcp (Ipv4Address::GetAny (), servPort);
-  ApplicationContainer apps = sink.Build (c1.Get (1));
+  ApplicationContainer apps = sink.Install (c1.Get (1));
   apps.Start (Seconds (0.0));
 
   // and generate traffic to remote sink.
--- a/examples/udp-echo.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/udp-echo.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -80,7 +80,7 @@
   n.Create (4);
 
   InternetStackHelper internet;
-  internet.Build (n);
+  internet.Install (n);
 
   NS_LOG_INFO ("Create channels.");
 //
@@ -89,7 +89,7 @@
   CsmaHelper csma;
   csma.SetChannelParameter ("BitRate", DataRate(5000000));
   csma.SetChannelParameter ("Delay", MilliSeconds (2));
-  NetDeviceContainer d = csma.Build (n);
+  NetDeviceContainer d = csma.Install (n);
 
   Ipv4AddressHelper ipv4;
 //
@@ -106,7 +106,7 @@
   uint16_t port = 9;  // well-known echo port number
   UdpEchoServerHelper server;
   server.SetPort (port);
-  ApplicationContainer apps = server.Build (n.Get(1));
+  ApplicationContainer apps = server.Install (n.Get(1));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
@@ -122,7 +122,7 @@
   client.SetAppAttribute ("MaxPackets", Uinteger (maxPacketCount));
   client.SetAppAttribute ("Interval", interPacketInterval);
   client.SetAppAttribute ("PacketSize", Uinteger (packetSize));
-  apps = client.Build (n.Get (0));
+  apps = client.Install (n.Get (0));
   apps.Start (Seconds (2.0));
   apps.Stop (Seconds (10.0));
 
--- a/examples/wifi-adhoc.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/wifi-adhoc.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -115,9 +115,9 @@
   c.Create (2);
 
   PacketSocketHelper packetSocket;
-  packetSocket.Build (c);
+  packetSocket.Install (c);
 
-  NetDeviceContainer devices = wifi.Build (c);
+  NetDeviceContainer devices = wifi.Install (c);
 
   MobilityHelper mobility;
   Ptr<ListPositionAllocator> positionAlloc = CreateObject<ListPositionAllocator> ();
@@ -134,7 +134,7 @@
   onoff.SetAppAttribute ("DataRate", DataRate (60000000));
   onoff.SetAppAttribute ("PacketSize", Uinteger (2000));
   onoff.SetPacketRemote (devices.Get (0), devices.Get (1)->GetAddress (), 1);
-  ApplicationContainer apps = onoff.Build (c.Get (0));
+  ApplicationContainer apps = onoff.Install (c.Get (0));
   apps.Start (Seconds (0.5));
   apps.Stop (Seconds (250.0));
 
--- a/examples/wifi-ap.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/examples/wifi-ap.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -128,8 +128,8 @@
   ap.Create (1);
 
   // give packet socket powers to nodes.
-  packetSocket.Build (stas);
-  packetSocket.Build (ap);
+  packetSocket.Install (stas);
+  packetSocket.Install (ap);
 
   Ptr<WifiChannel> channel = CreateObject<WifiChannel> ();
   channel->SetPropagationDelayModel (CreateObject<ConstantSpeedPropagationDelayModel> ());
@@ -143,12 +143,12 @@
   // setup stas.
   wifi.SetMac ("ns3::NqstaWifiMac", "Ssid", ssid,
                "ActiveProbing", Boolean (false));
-  staDevs = wifi.Build (stas, channel);
+  staDevs = wifi.Install (stas, channel);
   // setup ap.
   wifi.SetMac ("ns3::NqapWifiMac", "Ssid", ssid,
                "BeaconGeneration", Boolean (true),
                "BeaconInterval", Seconds (2.5));
-  wifi.Build (ap, channel);
+  wifi.Install (ap, channel);
 
   // mobility.
   mobility.Layout (stas);
@@ -160,7 +160,7 @@
   onoff.SetAppAttribute ("OnTime", ConstantVariable (42));
   onoff.SetAppAttribute ("OffTime", ConstantVariable (0));
   onoff.SetPacketRemote (staDevs.Get (0), staDevs.Get (1)->GetAddress (), 1);
-  ApplicationContainer apps = onoff.Build (stas.Get (0));
+  ApplicationContainer apps = onoff.Install (stas.Get (0));
   apps.Start (Seconds (0.5));
   apps.Stop (Seconds (43.0));
 
--- a/samples/main-simple.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/samples/main-simple.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -41,7 +41,7 @@
   c.Create (1);
 
   InternetStackHelper internet;
-  internet.Build (c);
+  internet.Install (c);
 
 
   TypeId tid = TypeId::LookupByName ("ns3::Udp");
--- a/src/helper/csma-helper.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/csma-helper.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -157,14 +157,14 @@
 
 
 NetDeviceContainer 
-CsmaHelper::Build (const NodeContainer &c)
+CsmaHelper::Install (const NodeContainer &c)
 {
   Ptr<CsmaChannel> channel = m_channelFactory.Create ()->GetObject<CsmaChannel> ();
-  return Build (c, channel);
+  return Install (c, channel);
 }
 
 NetDeviceContainer 
-CsmaHelper::Build (const NodeContainer &c, Ptr<CsmaChannel> channel)
+CsmaHelper::Install (const NodeContainer &c, Ptr<CsmaChannel> channel)
 {
   NetDeviceContainer container;
   for (NodeContainer::Iterator i = c.Begin (); i != c.End (); i++)
--- a/src/helper/internet-stack-helper.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/internet-stack-helper.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -28,7 +28,7 @@
 std::string InternetStackHelper::m_pcapBaseFilename;
 
 void 
-InternetStackHelper::Build (NodeContainer c)
+InternetStackHelper::Install (NodeContainer c)
 {
   for (NodeContainer::Iterator i = c.Begin (); i != c.End (); ++i)
     {
--- a/src/helper/internet-stack-helper.h	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/internet-stack-helper.h	Mon Apr 07 10:38:37 2008 -0700
@@ -39,7 +39,7 @@
    * For each node in the input container, aggregate implementations
    * of the ns3::Ipv4, ns3::Udp, and, ns3::Tcp classes.
    */
-  void Build (NodeContainer c);
+  void Install (NodeContainer c);
 
   /**
    * \param filename filename prefix to use for pcap files.
--- a/src/helper/on-off-helper.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/on-off-helper.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -59,7 +59,7 @@
 }
 
 ApplicationContainer
-OnOffHelper::Build (NodeContainer c)
+OnOffHelper::Install (NodeContainer c)
 {
   ApplicationContainer apps;
   for (NodeContainer::Iterator i = c.Begin (); i != c.End (); ++i)
--- a/src/helper/on-off-helper.h	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/on-off-helper.h	Mon Apr 07 10:38:37 2008 -0700
@@ -42,7 +42,7 @@
   
   void SetAppAttribute (std::string name, Attribute value);
 
-  ApplicationContainer Build (NodeContainer c);
+  ApplicationContainer Install (NodeContainer c);
 
 private:
   std::string m_protocol;
--- a/src/helper/packet-sink-helper.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/packet-sink-helper.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -42,7 +42,7 @@
 }
 
 ApplicationContainer 
-PacketSinkHelper::Build (NodeContainer c)
+PacketSinkHelper::Install (NodeContainer c)
 {
   ApplicationContainer apps;
   for (NodeContainer::Iterator i = c.Begin (); i != c.End (); ++i)
--- a/src/helper/packet-sink-helper.h	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/packet-sink-helper.h	Mon Apr 07 10:38:37 2008 -0700
@@ -35,7 +35,7 @@
   void SetupUdp (Ipv4Address ip, uint16_t port);
   void SetupTcp (Ipv4Address ip, uint16_t port);
 
-  ApplicationContainer Build (NodeContainer c);
+  ApplicationContainer Install (NodeContainer c);
 private:
   ObjectFactory m_factory;
 };
--- a/src/helper/packet-socket-helper.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/packet-socket-helper.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -4,7 +4,7 @@
 namespace ns3 {
 
 void 
-PacketSocketHelper::Build (NodeContainer c)
+PacketSocketHelper::Install (NodeContainer c)
 {
   for (NodeContainer::Iterator i = c.Begin (); i != c.End (); ++i)
     {
--- a/src/helper/packet-socket-helper.h	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/packet-socket-helper.h	Mon Apr 07 10:38:37 2008 -0700
@@ -17,7 +17,7 @@
    * For each node in the input container, aggregate a ns3::PacketSocketFactory
    * object instance.
    */
-  void Build (NodeContainer c);
+  void Install (NodeContainer c);
 };
 
 } // namespace ns3
--- a/src/helper/point-to-point-helper.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/point-to-point-helper.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -156,13 +156,13 @@
 }
 
 NetDeviceContainer 
-PointToPointHelper::Build (NodeContainer c)
+PointToPointHelper::Install (NodeContainer c)
 {
   NS_ASSERT (c.GetN () == 2);
-  return Build (c.Get (0), c.Get (1));
+  return Install (c.Get (0), c.Get (1));
 }
 NetDeviceContainer 
-PointToPointHelper::Build (Ptr<Node> a, Ptr<Node> b)
+PointToPointHelper::Install (Ptr<Node> a, Ptr<Node> b)
 {
   NetDeviceContainer container;
 
--- a/src/helper/udp-echo-helper.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/udp-echo-helper.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -34,7 +34,7 @@
   m_port = port;
 }
 ApplicationContainer 
-UdpEchoServerHelper::Build (NodeContainer c)
+UdpEchoServerHelper::Install (NodeContainer c)
 {
   ApplicationContainer apps;
   for (NodeContainer::Iterator i = c.Begin (); i != c.End (); ++i)
@@ -64,7 +64,7 @@
 }
 
 ApplicationContainer 
-UdpEchoClientHelper::Build (NodeContainer c)
+UdpEchoClientHelper::Install (NodeContainer c)
 {
   ApplicationContainer apps;
   for (NodeContainer::Iterator i = c.Begin (); i != c.End (); ++i)
--- a/src/helper/udp-echo-helper.h	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/udp-echo-helper.h	Mon Apr 07 10:38:37 2008 -0700
@@ -33,7 +33,7 @@
 public:
   UdpEchoServerHelper ();
   void SetPort (uint16_t port);
-  ApplicationContainer Build (NodeContainer c);
+  ApplicationContainer Install (NodeContainer c);
 private:
   uint16_t m_port;
 };
@@ -45,7 +45,7 @@
 
   void SetRemote (Ipv4Address ip, uint16_t port);
   void SetAppAttribute (std::string name, Attribute value);
-  ApplicationContainer Build (NodeContainer c);
+  ApplicationContainer Install (NodeContainer c);
  private:
   ObjectFactory m_factory;
   Ipv4Address m_remoteIp;
--- a/src/helper/wifi-helper.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/wifi-helper.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -231,17 +231,17 @@
 }
 
 NetDeviceContainer
-WifiHelper::Build (NodeContainer c) const
+WifiHelper::Install (NodeContainer c) const
 {
   Ptr<WifiChannel> channel = CreateObject<WifiChannel> ();
   channel->SetPropagationDelayModel (CreateObject<ConstantSpeedPropagationDelayModel> ());
   Ptr<LogDistancePropagationLossModel> log = CreateObject<LogDistancePropagationLossModel> ();
   log->SetReferenceModel (CreateObject<FriisPropagationLossModel> ());
   channel->SetPropagationLossModel (log);
-  return Build (c, channel);
+  return Install (c, channel);
 }
 NetDeviceContainer
-WifiHelper::Build (NodeContainer c, Ptr<WifiChannel> channel) const
+WifiHelper::Install (NodeContainer c, Ptr<WifiChannel> channel) const
 {
   NetDeviceContainer devices;
   for (NodeContainer::Iterator i = c.Begin (); i != c.End (); i++)
--- a/src/helper/wifi-helper.h	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/wifi-helper.h	Mon Apr 07 10:38:37 2008 -0700
@@ -229,7 +229,7 @@
    * attributes specified in WifiHelper::SetRemoteStationManager, 
    * WifiHelper::SetMac, and, WifiHelper::SetPhy.
    */
-  NetDeviceContainer Build (NodeContainer c) const;
+  NetDeviceContainer Install (NodeContainer c) const;
   /**
    * \param channel a channel to use
    * \param c a set of nodes
@@ -244,7 +244,7 @@
    * The user is expected to attach to the input channel a proper 
    * ns3::PropagationLossModel, and ns3::PropagationDelayModel.
    */
-  NetDeviceContainer Build (NodeContainer c, Ptr<WifiChannel> channel) const;
+  NetDeviceContainer Install (NodeContainer c, Ptr<WifiChannel> channel) const;
 
 private:
   ObjectFactory m_stationManager;
--- a/tutorial/tutorial-bus-network.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/tutorial/tutorial-bus-network.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -37,12 +37,12 @@
   n.Create (10);
 
   InternetStackHelper internet;
-  internet.Build (n);
+  internet.Install (n);
 
   CsmaHelper csma;
   csma.SetChannelParameter ("BitRate", DataRate(10000000));
   csma.SetChannelParameter ("Delay", MilliSeconds(20));
-  NetDeviceContainer nd = csma.Build (n);
+  NetDeviceContainer nd = csma.Install (n);
 
   Ipv4AddressHelper ipv4;
   ipv4.SetBase ("10.1.0.0", "255.255.0.0", "0.0.0.3");
@@ -54,13 +54,13 @@
   client.SetAppAttribute ("MaxPackets", Uinteger (1));
   client.SetAppAttribute ("Interval", Seconds (1.0));
   client.SetAppAttribute ("PacketSize", Uinteger (1024));
-  ApplicationContainer apps = client.Build (n.Get (0));
+  ApplicationContainer apps = client.Install (n.Get (0));
   apps.Start (Seconds (2.0));
   apps.Stop (Seconds (10.0));
 
   UdpEchoServerHelper server;
   server.SetPort (port);
-  apps = server.Build (n.Get (1));
+  apps = server.Install (n.Get (1));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
--- a/tutorial/tutorial-csma-echo-ascii-trace.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/tutorial/tutorial-csma-echo-ascii-trace.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -35,12 +35,12 @@
   n.Create (4);
 
   InternetStackHelper internet;
-  internet.Build (n);
+  internet.Install (n);
 
   CsmaHelper csma;
   csma.SetChannelParameter ("BitRate", DataRate (5000000));
   csma.SetChannelParameter ("Delay", MilliSeconds (2));
-  NetDeviceContainer nd = csma.Build (n);
+  NetDeviceContainer nd = csma.Install (n);
 
   Ipv4AddressHelper ipv4;
   ipv4.SetBase ("10.1.1.0", "255.255.255.0");
@@ -53,13 +53,13 @@
   client.SetAppAttribute ("MaxPackets", Uinteger (1));
   client.SetAppAttribute ("Interval", Seconds (1.0));
   client.SetAppAttribute ("PacketSize", Uinteger (1024));
-  ApplicationContainer apps = client.Build (n.Get (0));
+  ApplicationContainer apps = client.Install (n.Get (0));
   apps.Start (Seconds (2.0));
   apps.Stop (Seconds (10.0));
 
   UdpEchoServerHelper server;
   server.SetPort (port);
-  apps = server.Build (n.Get (1));
+  apps = server.Install (n.Get (1));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
--- a/tutorial/tutorial-csma-echo-pcap-trace.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/tutorial/tutorial-csma-echo-pcap-trace.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -33,12 +33,12 @@
   n.Create (4);
 
   InternetStackHelper internet;
-  internet.Build (n);
+  internet.Install (n);
 
   CsmaHelper csma;
   csma.SetChannelParameter ("BitRate", DataRate (5000000));
   csma.SetChannelParameter ("Delay", MilliSeconds (2));
-  NetDeviceContainer nd = csma.Build (n);
+  NetDeviceContainer nd = csma.Install (n);
 
   Ipv4AddressHelper ipv4;
   ipv4.SetBase ("10.1.1.0", "255.255.255.0");
@@ -51,13 +51,13 @@
   client.SetAppAttribute ("MaxPackets", Uinteger (1));
   client.SetAppAttribute ("Interval", Seconds (1.0));
   client.SetAppAttribute ("PacketSize", Uinteger (1024));
-  ApplicationContainer apps = client.Build (n.Get (0));
+  ApplicationContainer apps = client.Install (n.Get (0));
   apps.Start (Seconds (2.0));
   apps.Stop (Seconds (10.0));
 
   UdpEchoServerHelper server;
   server.SetPort (port);
-  apps = server.Build (n.Get (1));
+  apps = server.Install (n.Get (1));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
--- a/tutorial/tutorial-csma-echo.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/tutorial/tutorial-csma-echo.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -33,12 +33,12 @@
   n.Create (4);
 
   InternetStackHelper internet;
-  internet.Build (n);
+  internet.Install (n);
 
   CsmaHelper csma;
   csma.SetChannelParameter ("BitRate", DataRate (5000000));
   csma.SetChannelParameter ("Delay", MilliSeconds (2));
-  NetDeviceContainer nd = csma.Build (n);
+  NetDeviceContainer nd = csma.Install (n);
 
   Ipv4AddressHelper ipv4;
   ipv4.SetBase ("10.1.1.0", "255.255.255.0");
@@ -51,13 +51,13 @@
   client.SetAppAttribute ("MaxPackets", Uinteger (1));
   client.SetAppAttribute ("Interval", Seconds (1.0));
   client.SetAppAttribute ("PacketSize", Uinteger (1024));
-  ApplicationContainer apps = client.Build (n.Get (0));
+  ApplicationContainer apps = client.Install (n.Get (0));
   apps.Start (Seconds (2.0));
   apps.Stop (Seconds (10.0));
 
   UdpEchoServerHelper server;
   server.SetPort (port);
-  apps = server.Build (n.Get (1));
+  apps = server.Install (n.Get (1));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
   
--- a/tutorial/tutorial-linear-dumbbell.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/tutorial/tutorial-linear-dumbbell.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -50,12 +50,12 @@
   lan1.Create (4);
 
   InternetStackHelper internet;
-  internet.Build (lan1);
+  internet.Install (lan1);
 
   CsmaHelper csma;
   csma.SetChannelParameter ("BitRate", DataRate (10000000));
   csma.SetChannelParameter ("Delay", MilliSeconds (2));
-  NetDeviceContainer dev1 = csma.Build (lan1);
+  NetDeviceContainer dev1 = csma.Install (lan1);
   Ipv4AddressHelper ipv4;
   ipv4.SetBase ("10.1.1.0", "255.255.255.0");
   Ipv4InterfaceContainer i1 = ipv4.Allocate (dev1);
@@ -66,9 +66,9 @@
 //
   NodeContainer lan2;
   lan2.Create (4);
-  internet.Build (lan2);
+  internet.Install (lan2);
 
-  NetDeviceContainer dev2 = csma.Build (lan2);
+  NetDeviceContainer dev2 = csma.Install (lan2);
   ipv4.SetBase ("10.1.2.0", "255.255.255.0");
   Ipv4InterfaceContainer i2 = ipv4.Allocate (dev2);
 
@@ -80,7 +80,7 @@
   PointToPointHelper p2p;
   p2p.SetChannelParameter ("BitRate", DataRate (38400));
   p2p.SetChannelParameter ("Delay", MilliSeconds (20));
-  NetDeviceContainer dev3 = p2p.Build (backbone);
+  NetDeviceContainer dev3 = p2p.Install (backbone);
   ipv4.SetBase ("10.1.3.0", "255.255.255.0");
   ipv4.Allocate (dev3);
 
@@ -98,38 +98,38 @@
   client.SetAppAttribute ("MaxPackets", Uinteger (100));
   client.SetAppAttribute ("Interval", Seconds (0.01));
   client.SetAppAttribute ("PacketSize", Uinteger (1024));
-  ApplicationContainer apps = client.Build (lan1.Get (0));
+  ApplicationContainer apps = client.Install (lan1.Get (0));
   apps.Start (Seconds(2.));
   apps.Stop (Seconds (10.0));
 
   client.SetRemote (i2.GetAddress (1), port);
-  apps = client.Build (lan1.Get (1));
+  apps = client.Install (lan1.Get (1));
   apps.Start (Seconds(2.1));
   apps.Stop (Seconds (10.0));
   
   client.SetRemote (i2.GetAddress (2), port);
-  apps = client.Build (lan1.Get (2));
+  apps = client.Install (lan1.Get (2));
   apps.Start (Seconds(2.2));
   apps.Stop (Seconds (10.0));
 
   client.SetRemote (i2.GetAddress (3), port);
-  apps = client.Build (lan1.Get (3));
+  apps = client.Install (lan1.Get (3));
   apps.Start (Seconds(2.3));
   apps.Stop (Seconds (10.0));
 
 
   UdpEchoServerHelper server;
   server.SetPort (port);
-  apps = server.Build (lan2.Get (0));
+  apps = server.Install (lan2.Get (0));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
-  apps = server.Build (lan2.Get (1));
+  apps = server.Install (lan2.Get (1));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
-  apps = server.Build (lan2.Get (2));
+  apps = server.Install (lan2.Get (2));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
-  apps = server.Build (lan2.Get (3));
+  apps = server.Install (lan2.Get (3));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
--- a/tutorial/tutorial-point-to-point.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/tutorial/tutorial-point-to-point.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -42,12 +42,12 @@
   n.Create (2);
 
   InternetStackHelper internet;
-  internet.Build (n);
+  internet.Install (n);
 
   PointToPointHelper p2p;
   p2p.SetChannelParameter ("BitRate", DataRate (38400));
   p2p.SetChannelParameter ("Delay", MilliSeconds (20));
-  NetDeviceContainer nd = p2p.Build (n);
+  NetDeviceContainer nd = p2p.Install (n);
 
   Ipv4AddressHelper ipv4;
   ipv4.SetBase ("10.1.1.0", "255.255.255.252");
@@ -59,13 +59,13 @@
   client.SetAppAttribute ("MaxPackets", Uinteger (1));
   client.SetAppAttribute ("Interval", Seconds (1.0));
   client.SetAppAttribute ("PacketSize", Uinteger (1024));
-  ApplicationContainer apps = client.Build (n.Get (0));
+  ApplicationContainer apps = client.Install (n.Get (0));
   apps.Start (Seconds (2.0));
   apps.Stop (Seconds (10.0));
   
   UdpEchoServerHelper server;
   server.SetPort (port);
-  apps = server.Build (n.Get (1));
+  apps = server.Install (n.Get (1));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
--- a/tutorial/tutorial-star-routing.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/tutorial/tutorial-star-routing.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -53,18 +53,18 @@
   NodeContainer n06 = NodeContainer (n.Get (0), n.Get (6));
 
   InternetStackHelper internet;
-  internet.Build (n);
+  internet.Install (n);
 
   PointToPointHelper p2p;
   p2p.SetChannelParameter ("BitRate", DataRate (38400));
   p2p.SetChannelParameter ("Delay", MilliSeconds (20));
 
-  NetDeviceContainer d01 = p2p.Build (n01);
-  NetDeviceContainer d02 = p2p.Build (n02);
-  NetDeviceContainer d03 = p2p.Build (n03);
-  NetDeviceContainer d04 = p2p.Build (n04);
-  NetDeviceContainer d05 = p2p.Build (n05);
-  NetDeviceContainer d06 = p2p.Build (n06);
+  NetDeviceContainer d01 = p2p.Install (n01);
+  NetDeviceContainer d02 = p2p.Install (n02);
+  NetDeviceContainer d03 = p2p.Install (n03);
+  NetDeviceContainer d04 = p2p.Install (n04);
+  NetDeviceContainer d05 = p2p.Install (n05);
+  NetDeviceContainer d06 = p2p.Install (n06);
 
   Ipv4AddressHelper ipv4;
   ipv4.SetBase ("10.1.1.0", "255.255.255.252");
@@ -84,7 +84,7 @@
 
   UdpEchoServerHelper server;
   server.SetPort (port);
-  ApplicationContainer apps = server.Build (n.Get (1));
+  ApplicationContainer apps = server.Install (n.Get (1));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
@@ -93,7 +93,7 @@
   client.SetAppAttribute ("MaxPackets", Uinteger (1));
   client.SetAppAttribute ("Interval", Seconds (1.0));
   client.SetAppAttribute ("PacketSize", Uinteger (1024));
-  apps = client.Build (n.Get (0));
+  apps = client.Install (n.Get (0));
   apps.Start (Seconds (2.0));
   apps.Stop (Seconds (10.0));
 
--- a/tutorial/tutorial-star.cc	Sun Apr 06 21:57:11 2008 +0100
+++ b/tutorial/tutorial-star.cc	Mon Apr 07 10:38:37 2008 -0700
@@ -52,18 +52,18 @@
   NodeContainer n06 = NodeContainer (n.Get (0), n.Get (6));
 
   InternetStackHelper internet;
-  internet.Build (n);
+  internet.Install (n);
 
   PointToPointHelper p2p;
   p2p.SetChannelParameter ("BitRate", DataRate (38400));
   p2p.SetChannelParameter ("Delay", MilliSeconds (20));
 
-  NetDeviceContainer d01 = p2p.Build (n01);
-  NetDeviceContainer d02 = p2p.Build (n02);
-  NetDeviceContainer d03 = p2p.Build (n03);
-  NetDeviceContainer d04 = p2p.Build (n04);
-  NetDeviceContainer d05 = p2p.Build (n05);
-  NetDeviceContainer d06 = p2p.Build (n06);
+  NetDeviceContainer d01 = p2p.Install (n01);
+  NetDeviceContainer d02 = p2p.Install (n02);
+  NetDeviceContainer d03 = p2p.Install (n03);
+  NetDeviceContainer d04 = p2p.Install (n04);
+  NetDeviceContainer d05 = p2p.Install (n05);
+  NetDeviceContainer d06 = p2p.Install (n06);
 
   Ipv4AddressHelper ipv4;
   ipv4.SetBase ("10.1.1.0", "255.255.255.252");
@@ -83,7 +83,7 @@
 
   UdpEchoServerHelper server;
   server.SetPort (port);
-  ApplicationContainer apps = server.Build (n.Get (1));
+  ApplicationContainer apps = server.Install (n.Get (1));
   apps.Start (Seconds (1.0));
   apps.Stop (Seconds (10.0));
 
@@ -92,7 +92,7 @@
   client.SetAppAttribute ("MaxPackets", Uinteger (1));
   client.SetAppAttribute ("Interval", Seconds (1.0));
   client.SetAppAttribute ("PacketSize", Uinteger (1024));
-  apps = client.Build (n.Get (0));
+  apps = client.Install (n.Get (0));
   apps.Start (Seconds (2.0));
   apps.Stop (Seconds (10.0));
--- a/src/helper/csma-helper.h	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/csma-helper.h	Mon Apr 07 10:38:37 2008 -0700
@@ -53,7 +53,7 @@
    * \param v4 the value of the attribute to set on the queue
    *
    * Set the type of queue to create and associated to each
    * CsmaNetDevice created through CsmaHelper::Build.
    */
   void SetQueue (std::string type,
 		 std::string n1 = "", Attribute v1 = Attribute (),
@@ -66,7 +66,7 @@
    * \param v1 the value of the attribute to set
    *
    * Set these parameters on each ns3::CsmaNetDevice created
-   * by CsmaHelper::Build
+   * by CsmaHelper::Install
    */
   void SetDeviceParameter (std::string n1, Attribute v1);
 
@@ -75,7 +75,7 @@
    * \param v1 the value of the attribute to set
    *
    * Set these parameters on each ns3::CsmaChannel created
-   * by CsmaHelper::Build
+   * by CsmaHelper::Install
    */
   void SetChannelParameter (std::string n1, Attribute v1);
 
@@ -161,9 +161,9 @@
    *
    * This method creates a simple ns3::CsmaChannel with the
    * attributes configured by CsmaHelper::SetChannelParameter and
    * then calls CsmaHelper::Build.
    */
-  NetDeviceContainer Build (const NodeContainer &c);
+  NetDeviceContainer Install (const NodeContainer &c);
 
   /**
    * \param c a set of nodes
@@ -173,7 +173,7 @@
    * the requested parameters, a queue for this NetDevice, and associate
    * the resulting ns3::NetDevice with the ns3::Node and ns3::CsmaChannel.
    */
-  NetDeviceContainer Build (const NodeContainer &c, Ptr<CsmaChannel> channel);
+  NetDeviceContainer Install (const NodeContainer &c, Ptr<CsmaChannel> channel);
 
 private:
   static void RxEvent (Ptr<PcapWriter> writer, Ptr<const Packet> packet);
@@ -53,7 +53,7 @@
    *
    * Set the type of queue to create and associated to each
-   * CsmaNetDevice created through CsmaHelper::Build.
+   * CsmaNetDevice created through CsmaHelper::Install.
    */
   void SetQueue (std::string type,
@@ -161,9 +161,9 @@
    * This method creates a simple ns3::CsmaChannel with the
    * attributes configured by CsmaHelper::SetChannelParameter and
-   * then calls CsmaHelper::Build.
+   * then calls CsmaHelper::Install.
    */
--- a/src/helper/point-to-point-helper.h	Sun Apr 06 21:57:11 2008 +0100
+++ b/src/helper/point-to-point-helper.h	Mon Apr 07 10:38:37 2008 -0700
@@ -53,7 +53,7 @@
    * \param v4 the value of the attribute to set on the queue
    *
    * Set the type of queue to create and associated to each
    * PointToPointNetDevice created through PointToPointHelper::Build.
    */
   void SetQueue (std::string type,
 		 std::string n1 = "", Attribute v1 = Attribute (),
@@ -66,7 +66,7 @@
    * \param value the value of the attribute to set
    *
    * Set these parameters on each ns3::PointToPointNetDevice created
-   * by PointToPointHelper::Build
+   * by PointToPointHelper::Install
    */
   void SetDeviceParameter (std::string name, Attribute value);
   /**
@@ -74,7 +74,7 @@
    * \param value the value of the attribute to set
    *
    * Set these parameters on each ns3::PointToPointChannel created
-   * by PointToPointHelper::Build
+   * by PointToPointHelper::Install
    */
   void SetChannelParameter (std::string name, Attribute value);
 
@@ -165,14 +165,14 @@
    * a queue for this ns3::NetDevice, and associate the resulting 
    * ns3::NetDevice with the ns3::Node and ns3::PointToPointChannel.
    */
-  NetDeviceContainer Build (NodeContainer c);
+  NetDeviceContainer Install (NodeContainer c);
   /**
    * \param a first node
    * \param b second node
    *
    * Saves you from having to construct a temporary NodeContainer.
    */
-  NetDeviceContainer Build (Ptr<Node> a, Ptr<Node> b);
+  NetDeviceContainer Install (Ptr<Node> a, Ptr<Node> b);
 
 private:
   void EnablePcap (Ptr<Node> node, Ptr<NetDevice> device, Ptr<Queue> queue);
@@ -53,7 +53,7 @@
    *
    * Set the type of queue to create and associated to each
-   * PointToPointNetDevice created through PointToPointHelper::Build.
+   * PointToPointNetDevice created through PointToPointHelper::Install.
    */
   void SetQueue (std::string type,